==> kde4pim_3.92.0.orig.tar.gz: kdepim-3.92.0/akonadi/server/src/handler/list.h <==
/***************************************************************************
 *   Copyright (C) 2006 by Till Adam <adam@kde.org>                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef AKONADILIST_H
#define AKONADILIST_H

#include <handler.h>
#include "akonadi_export.h"

namespace Akonadi {

class Location;

/**
  @ingroup akoandi_server_handler

  Handler for the list command.
 */
class AKONADI_SERVER_EXPORT List : public Handler
{
public:
    List();

    ~List();

    bool handleLine(const QByteArray& line);

private:
    virtual bool listCollections( const QString& prefix,
                                            const QString& mailboxPattern,
                                            QList<Location> &result );

};

}

#endif

==> kde4pim_3.94.0.orig.tar.gz: kdepim-3.94.0/akonadi/server/src/handler/list.h <==
/***************************************************************************
 *   Copyright (C) 2006 by Till Adam <adam@kde.org>                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef AKONADILIST_H
#define AKONADILIST_H

#include <handler.h>
#include "akonadi_export.h"

namespace Akonadi {

class Location;

/**
  @ingroup akonadi_server_handler

  Handler for the list command.
 */
class AKONADI_SERVER_EXPORT List : public Handler
{
public:
    List();

    ~List();

    bool handleLine(const QByteArray& line);

private:
    virtual bool listCollections( const QString& prefix,
                                            const QString& mailboxPattern,
                                            QList<Location> &result );

};

}

#endif
